Class: SwarmSDK::ValidationResult Private

Inherits:
Object
  • Object
show all
Defined in:
lib/swarm_sdk/validation_result.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Internal result object for validation phase during snapshot restore

Used during restore to track which agents can be restored and which need to be skipped due to configuration mismatches.

API:

  • private

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(warnings:, skipped_agents:, restorable_agents:, skipped_delegations:, restorable_delegations:) ⇒ ValidationResult

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Initialize validation result

Parameters:

  • Warning messages with details

  • Names of agents that can't be restored

  • Names of agents that can be restored

  • Names of delegations that can't be restored

  • Names of delegations that can be restored

API:

  • private



24
25
26
27
28
29
30
31
# File 'lib/swarm_sdk/validation_result.rb', line 24

def initialize(warnings:, skipped_agents:, restorable_agents:,
  skipped_delegations:, restorable_delegations:)
  @warnings = warnings
  @skipped_agents = skipped_agents
  @restorable_agents = restorable_agents
  @skipped_delegations = skipped_delegations
  @restorable_delegations = restorable_delegations
end

Instance Attribute Details

#restorable_agentsObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



11
12
13
# File 'lib/swarm_sdk/validation_result.rb', line 11

def restorable_agents
  @restorable_agents
end

#restorable_delegationsObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



11
12
13
# File 'lib/swarm_sdk/validation_result.rb', line 11

def restorable_delegations
  @restorable_delegations
end

#skipped_agentsObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



11
12
13
# File 'lib/swarm_sdk/validation_result.rb', line 11

def skipped_agents
  @skipped_agents
end

#skipped_delegationsObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



11
12
13
# File 'lib/swarm_sdk/validation_result.rb', line 11

def skipped_delegations
  @skipped_delegations
end

#warningsObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



11
12
13
# File 'lib/swarm_sdk/validation_result.rb', line 11

def warnings
  @warnings
end