Class: SwarmSDK::ValidationResult Private
- Inherits:
-
Object
- Object
- SwarmSDK::ValidationResult
- Defined in:
- lib/swarm_sdk/validation_result.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Internal result object for validation phase during snapshot restore
Used during restore to track which agents can be restored and which need to be skipped due to configuration mismatches.
Instance Attribute Summary collapse
- #restorable_agents ⇒ Object readonly private
- #restorable_delegations ⇒ Object readonly private
- #skipped_agents ⇒ Object readonly private
- #skipped_delegations ⇒ Object readonly private
- #warnings ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(warnings:, skipped_agents:, restorable_agents:, skipped_delegations:, restorable_delegations:) ⇒ ValidationResult
constructor
private
Initialize validation result.
Constructor Details
#initialize(warnings:, skipped_agents:, restorable_agents:, skipped_delegations:, restorable_delegations:) ⇒ ValidationResult
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Initialize validation result
24 25 26 27 28 29 30 31 |
# File 'lib/swarm_sdk/validation_result.rb', line 24 def initialize(warnings:, skipped_agents:, restorable_agents:, skipped_delegations:, restorable_delegations:) @warnings = warnings @skipped_agents = skipped_agents @restorable_agents = restorable_agents @skipped_delegations = skipped_delegations @restorable_delegations = restorable_delegations end |
Instance Attribute Details
#restorable_agents ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
11 12 13 |
# File 'lib/swarm_sdk/validation_result.rb', line 11 def restorable_agents @restorable_agents end |
#restorable_delegations ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
11 12 13 |
# File 'lib/swarm_sdk/validation_result.rb', line 11 def restorable_delegations @restorable_delegations end |
#skipped_agents ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
11 12 13 |
# File 'lib/swarm_sdk/validation_result.rb', line 11 def skipped_agents @skipped_agents end |
#skipped_delegations ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
11 12 13 |
# File 'lib/swarm_sdk/validation_result.rb', line 11 def skipped_delegations @skipped_delegations end |
#warnings ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
11 12 13 |
# File 'lib/swarm_sdk/validation_result.rb', line 11 def warnings @warnings end |